<?php  

defined('C5_EXECUTE') or die(_("Access Denied."));
/*
 * Socializer for c5
 *
 * @package Block Quoter
 * @author Dave Rogers <connect@skybluesofa.com>
 * @version 5.6.0.0.5.3
 * @copyright Copyright (c) 2014, Dave Rogers
 * @license http://www.concrete5.org/help/legal/commercial_add-on_license/ c5 Commercial Add-On License
 */

class SkybluesofaSocialConnectBlockController
		extends BlockController
{

	var $pobj;
	protected $btTable = 'btSkybluesofaSocialConnect';
	protected $btConnectionsTable = 'btSkybluesofaSocialConnections';
	protected $btInterfaceWidth = "640";
	protected $btInterfaceHeight = "400";
	protected $btWrapperClass = 'ccm-ui';
	protected $db = null;

	/**
	 * Used for localization. If we want to localize the name/description we have to include this
	 */
	public function getBlockTypeDescription()
	{
		return t("Displays your social icons on your site");
	}

	public function getBlockTypeName()
	{
		return t("Social Connect");
	}

	public function __construct($obj = null)
	{
		parent::__construct($obj);
		$this->db = Loader::db();
	}

	public function view()
	{
		$pkg = Loader::package('skybluesofa_social_share');
		echo "<!-- Social Share v" . $pkg->getPackageVersion() . " by Sky Blue Sofa -->";

		if (empty($this->iconSize))
			$this->iconSize = 32;
		if (empty($this->layout))
			$this->layout = 'horizontal';
		if (empty($this->showNames))
			$this->showNames = false;
		if (empty($this->animation))
			$this->animation = false;
		if (empty($this->tooltip))
			$this->tooltip = "Connect with me";
		$this->set('iconSize', $this->iconSize);
		$this->set('layout', $this->layout);
		$this->set('tooltip', $this->tooltip);
		$this->set('showNames', $this->showNames ? true : false);
		$this->set('openNewWindow', $this->openNewWindow ? true : false);
		$this->set('animation', $this->animation ? true : false);
		$networks = $this->getNetworks();
		foreach ($networks as $network) {
			if (empty($network['tooltip'])) {
				$network['tooltip'] = 'Connect with me on ' . $network['name'];
				if ($network['handle'] == 'email') {
					$tooltip = 'Connect with me via Email';
				} elseif ($network['handle'] == 'feed') {
					$tooltip = 'Subscribe to my feed';
				} elseif ($network['handle'] == 'website') {
					$tooltip = 'Connect with me on my Website';
				}
			}
		}
		$this->set('networks', $networks);
		$this->set('connections', $this->getConnections($this->bID));
	}

	function add()
	{
		if (empty($this->floating_offset))
			$this->floating_offset = "0";
		$this->set('floating_offset', $this->floating_offset);
		$this->set('networks', $this->getNetworks());
		$this->set('connections', $this->getConnections($this->bID));
	}

	function edit()
	{
		if (empty($this->floating_offset))
			$this->floating_offset = "0";
		$this->set('floating_offset', $this->floating_offset);
		$this->set('networks', $this->getNetworks());
		$this->set('connections', $this->getConnections($this->bID));
	}

	/*
	 * save block config
	 */

	public function save($args)
	{
		$args['floating_offset'] = empty($args['floating_offset']) ? '0' : $args['floating_offset'];
		parent::save($args);
		$this->saveConnections($this->bID, $args);
	}

	function duplicate($newBID)
	{
		parent::duplicate($newBID);
		$this->duplicateConnections($newBID);
	}

	public function getConnections($bID)
	{
		$po = $this->db->GetArray("SELECT * FROM " . $this->btConnectionsTable . " WHERE ordinal IS NOT NULL AND bID = ? ORDER BY ordinal", array($bID));
		$no = $this->db->GetArray("SELECT * FROM " . $this->btConnectionsTable . " WHERE ordinal IS NULL AND bID = ? ORDER BY connID", array($bID));
		$res = array_merge($po, $no);
		return $res;
	}

	public function saveConnections($bID, $args)
	{
		if (!isset($args['connection']) || !is_array($args['connection'])) {
			return false;
		}
		$this->deleteConnections($bID);
		$ordinal = 1;
		foreach ($args['connection']['connection'] as $key => $value) {

			if ($key && !empty($args['connection']['network'][$key]) && !empty($args['connection']['connection'][$key])) {
				//if (in_array($args['connection']['network'][$key], $this->getNetworks())) {
				$netconn['bID'] = $bID;
				$netconn['ordinal'] = $ordinal;
				$netconn['network'] = $args['connection']['network'][$key];
				if (($args['connection']['network'][$key] == 'email') && (strpos($args['connection']['connection'][$key], '@') !== false)) {
					$args['connection']['connection'][$key] = 'mailto:' . $args['connection']['connection'][$key];
				}
				$netconn['url'] = $args['connection']['connection'][$key];
				$netconn['tooltip'] = $args['connection']['tooltip'][$key];
				$this->addConnection($bID, $netconn);
				$ordinal++;
				//}
			}
		}
	}

	function duplicateConnections($newBID)
	{
		$b = $this->getBlockObject();
		$c = $b->getBlockCollectionObject();

		$res = $this->db->query("select * from " . $this->btTable . " where bID = ?", array($this->bID));
		$existingBlock = $res->fetchRow();

		if (count($existingBlock) > 0) {
			$oldBID = $existingBlock['bID'];

			$res = $this->db->GetArray("SELECT * FROM " . $this->btConnectionsTable . " WHERE bID=?", array($this->bID));
			$existingConnections = array('connection' => array());
			$existingConnections['connection']['network'][] = null;
			$existingConnections['connection']['connection'][] = null;
			$existingConnections['connection']['tooltip'][] = null;
			foreach ($res as $key => $connection) {
				$existingConnections['connection']['network'][] = $connection['network'];
				$existingConnections['connection']['connection'][] = $connection['url'];
				$existingConnections['connection']['tooltip'][] = $connection['tooltip'];
			}
			$this->saveConnections($newBID, $existingConnections);
		} else {
			return 0;
		}
	}

	public function addConnection($bID, $newNetConn)
	{
		if (!is_array($newNetConn)) {
			return false;
		}
		$netconn = array('bID' => $bID, 'ordinal' => null, 'network' => null, 'url' => null, 'tooltip' => nul);
		foreach ($netconn as $key => $value) {
			if (array_key_exists($key, $newNetConn)) {
				$netconn[$key] = $newNetConn[$key];
			}
		}

		$res = $this->db->Execute("INSERT INTO " . $this->btConnectionsTable . " (bID, ordinal, network, url, tooltip) VALUES (?, ?, ?, ?, ?)", $netconn);
		return $res;
	}

	public function deleteConnections($bID)
	{
		$res = $this->db->Execute("DELETE FROM " . $this->btConnectionsTable . " WHERE bID = ?", array($bID));
		return $res;
	}

	public function getNetworks()
	{
		$db = Loader::db();
		$this->networks = $db->GetArray("SELECT *
			FROM btSkybluesofaSocialNetworks
			WHERE id IN (SELECT MAX(id)
				       FROM btSkybluesofaSocialNetworks
				       GROUP by handle) and connect=1
			ORDER BY name;");
		return $this->networks;
	}

}
