<?php  

defined('C5_EXECUTE') or die(_("Access Denied."));
/*
 * Socializer for c5
 *
 * @package Block Quoter
 * @author Dave Rogers <connect@skybluesofa.com>
 * @version 5.6.0.0.5.3
 * @copyright Copyright (c) 2014, Dave Rogers
 * @license http://www.concrete5.org/help/legal/commercial_add-on_license/ c5 Commercial Add-On License
 */

class SkybluesofaSocialSharePackage
		extends Package
{

	protected $pkgHandle = 'skybluesofa_social_share';
	protected $appVersionRequired = '5.6.0';
	protected $pkgVersion = '5.6.0.0.6.1.6';

	public function getPackageName()
	{
		return t("Socializer");
	}

	public function getPackageDescription()
	{
		return t("Add social networking capabilities to your site.");
	}

	public function install()
	{
		Loader::model('SkybluesofaSocializerInstaller', 'skybluesofa_social_share');
		$preInstallationErrors = SkybluesofaSocializerInstaller::preInstallationCheck();
		if (!$preInstallationErrors) {
			$pkg = parent::install();
			SkybluesofaSocializerInstaller::install($pkg);
		} else {
			return $preInstallationErrors;
		}
	}

	public function upgrade()
	{
		Loader::model('SkybluesofaSocializerInstaller', 'skybluesofa_social_share');
		$preInstallationErrors = SkybluesofaSocializerInstaller::preInstallationCheck();
		if (!$preInstallationErrors) {
			parent::upgrade();
			$pkg = $this->getByID($this->getPackageID());
			SkybluesofaSocializerInstaller::upgrade($pkg);
		} else {
			return $preInstallationErrors;
		}
	}

	private function add_events()
	{
		Events::extend('on_composer_publish', 'SkybluesofaSocializerPagePromotion', 'post_on_publish', 'packages/skybluesofa_social_share/models/SkybluesofaSocializerPagePromotion.php');
	}

	public function on_start()
	{
		if (version_compare(APP_VERSION, '5.5.0', '>=')) {
			if (!$this->hasMultipleCIDs() && !$this->isInternalPage()) {
				$this->add_events();
				$this->add_interface_bar_buttons();
			}
		}
	}

	private function hasMultipleCIDs()
	{
		$hasMultipleCIDs = false;
		if (is_array($_GET['cID'])) {
			$hasMultipleCIDs = true;
		}
		return $hasMultipleCIDs;
	}

	private function isInternalPage()
	{
		$isInternalPage = false;
		$page = false;
		$path = $_SERVER['PATH_INFO'];
		$path = explode('/', $path);
		if (count($path)) {
			$page = array_pop($path);
			$page = strtolower($page);
		}
		if ($page) {
			$internalPages = array(
				'edit_collection_popup.php', 'sitemap_update.php', 'versions.php', 'sitemap_check_in', 'edit_block_popup'
			);
			if (in_array($page, $internalPages)) {
				$isInternalPage = true;
			}
		}
		return $isInternalPage;
	}

	private function add_interface_bar_buttons()
	{
		$req = Request::get();
		if ($req->getRequestCollectionPath() != '') {
			if (ENABLE_LEGACY_CONTROLLER_URLS) {
				$c = Page::getByPath($req->getRequestCollectionPath(), false);
			} else {
				$c = $req->getRequestedPage();
			}
		} else {
			$requestCollectionID = $req->getRequestCollectionID();
			if (is_array($requestCollectionID)) {
				$requestCollectionID = HOME_CID;
			}
			$c = Page::getByID($requestCollectionID, false);
		}
		$cID = ($c instanceof Collection) ? $c->cID : '0';
		$ihm = Loader::helper('concrete/interface/menu');
		$uh = Loader::helper('concrete/urls');
		$ihm->addPageHeaderMenuItem(
				'social_share_promote_page', 'Promote Page<br><span style="font-weight:normal;font-size:75%;opacity:.75;">via Social Media</span>', 'right', array(
			'dialog-title' => t('Promote Page via Social Media')
			, 'href' => $uh->getToolsUrl('promote_page', 'skybluesofa_social_share')
			, 'dialog-on-open' => "$('#ccm-page-edit-nav-social_share_promote_page').removeClass('ccm-nav-loading');$('#skybluesofa_promote_page_cID').val('" . $cID . "');"
			, 'dialog-width' => '500'
			, 'dialog-height' => "400"
			, 'dialog-modal' => "false"
			, 'class' => 'dialog-launch'
				), 'skybluesofa_social_share'
		);
	}

}
