<?php  

defined('C5_EXECUTE') or die(_("Access Denied."));
/*
 * Socializer for c5
 *
 * @package Block Quoter
 * @author Dave Rogers <connect@skybluesofa.com>
 * @version 5.6.0.0.5.3
 * @copyright Copyright (c) 2014, Dave Rogers
 * @license http://www.concrete5.org/help/legal/commercial_add-on_license/ c5 Commercial Add-On License
 */

class NetworkSocialPost
{

	public $settingsGroupName = '';
	public $settings = array();
	protected $prefix = '';
	protected $facebookPrefix = '';
	protected $pageName = '';
	protected $pageUrl = '';
	protected $pageShortUrl = '';
	protected $pageDescription = '';
	protected $pageThumbnail = '';
	protected $hashTags = '';
	protected $hashTagsGenerated = false;

	function __construct()
	{
		$this->getSettingsFromDB();
	}

	public function getSettings()
	{
		return $this->settings;
	}

	public function saveSetting($handle = false, $value = false)
	{
		$db = Loader::db();
		$sql = "UPDATE btSkybluesofaSocialPostSettings SET VALUE=? WHERE group_name=? AND handle=?";
		$values = array($value, $this->settingsGroupName, $handle);
		$db->execute($sql, $values);
		$this->settings[$handle] = array('value' => $value);
	}

	public function postOnPagePublish($cObj)
	{
		if (isset($this->settings['send_post']) && $this->settings['send_post']['value']) {
			//Log::addEntry(print_r($this->settings,true), 'Socializer');
			$cObj = $this->getRealPageObject($cObj);
			if (!$this->isComposerPage($cObj) && ($cObj->cvID == 2)) {
				return;
			}
			$this->generatePageInfo($cObj);
			$this->postToNetwork($this->generatePostContents());
		}
	}

	public function promotePage($cID, $prefix = false, $useHashTags = true)
	{
		$this->generatePageInfo($cID);
		if ($prefix !== false) {
			$this->settings['prefix']['value'] = trim($prefix);
			$this->prefix = trim($prefix);
		}
		if (!$useHashTags)
			$this->hashTags = '';
		return $this->postToNetwork($this->generatePostContents());
	}

	protected function postToNetwork()
	{
		
	}

	protected function generatePostContents()
	{
		
	}

	protected function getSettingsFromDB()
	{
		$db = Loader::db();
		$sql = "SELECT * FROM btSkybluesofaSocialPostSettings WHERE group_name='" . $this->settingsGroupName . "' ORDER BY handle";
		@$rs = $db->Execute($sql);
		if (is_object($rs)) {
			while ($row = $rs->FetchRow()) {
                if ($row['handle']=='prefix') {
                    $row['value'] = Loader::helper('json')->decode($row['value']);
                }
				$this->settings[$row['handle']] = array('title' => $row['title'], 'value' => $row['value']);
			}
		}
		$this->getSettings();
	}

	protected function getRealPageObject($cObj)
	{
		if (is_numeric($cObj)) {
			$cObj = Page::getByID($cObj);
		}
		return $cObj;
	}

	protected function isComposerPage($cObj)
	{
		$cObj = $this->getRealPageObject($cObj);
		$ct = CollectionType::getByID($cObj->getCollectionTypeID());
		if (!$ct->isCollectionTypeIncludedInComposer()) {
			return false;
		}
		return true;
	}

	protected function generatePageInfo($cObj)
	{
		$cObj = $this->getRealPageObject($cObj);
		$nh = Loader::helper('navigation');
		$uh = Loader::helper('url');
		$this->prefix = $this->getPrefix($cObj);
		$this->pageName = $cObj->getCollectionName();
		$this->pageUrl = $nh->getCollectionURL($cObj);
		$this->pageShortUrl = $uh->shortenURL($this->pageUrl);
		$this->pageDescription = $cObj->getCollectionDescription();
		$this->pageThumbnail = $this->getThumbnail($cObj);
		$this->hashTags = $this->getHashTags($cObj);
	}

	protected function getPrefix($cObj)
	{
		$ctID = $cObj->ctID;
		$defaultIndex = 0;
		$prefixes = $this->settings['prefix']['value'];
        if (!is_object($prefixes)) {
            $prefixes = Loader::helper('json')->decode($this->settings['prefix']['value']);
        }
		if (isset($prefixes->$ctID)) {
			return $prefixes->$ctID;
		} elseif (isset($prefixes->$defaultIndex)) {
			return $prefixes->$defaultIndex;
		} else {
			return '';
		}
	}

	protected function getThumbnail($cObj)
	{
		$cObj = $this->getRealPageObject($cObj);
		Loader::model('attribute/categories/collection');
        $db = Loader::db();
        $sql = "SELECT `value` FROM aoSkybluesofaSocialConfiguration WHERE handle='image_handle'";
        $image_attribute_handles = $db->getOne($sql);
        $image_attribute_handles = explode(',',$image_attribute_handles);
        foreach ($image_attribute_handles as $handle) {
            $handle = trim($handle);
            if ($handle) {
                $image = $cObj->getAttribute($handle);
                if (!empty($image)) {
                    break;
                }
            }
        }

		if ($image) {
			return BASE_URL . $image->getRelativePath();
		}
		return null;
	}

	protected function getHashTags($cObj)
	{
		$cObj = $this->getRealPageObject($cObj);
		$ht = array();
		Loader::model('attribute/categories/collection');
		$cak = CollectionAttributeKey::getByHandle('tags');
		$cav = $cObj->getCollectionAttributeValue($cak);
		if (is_object($cav)) {
			foreach ($cav->getOptions() as $opt) {
				$val = trim($opt->value);
				if ($val != '') {
					$ht[] = '#' . str_replace(' ', '', ucwords($val));
				}
			}
		}
		return implode(' ', $ht);
	}

}

?>