<?php  

defined('C5_EXECUTE') or die(_("Access Denied."));
/*
 * Socializer for c5
 *
 * @package Block Quoter
 * @author Dave Rogers <connect@skybluesofa.com>
 * @version 5.6.0.0.5.3
 * @copyright Copyright (c) 2014, Dave Rogers
 * @license http://www.concrete5.org/help/legal/commercial_add-on_license/ c5 Commercial Add-On License
 */

Loader::library('3rdParty/facebookauth/inc/facebook', 'skybluesofa_social_share');
Loader::model('social_post/network', 'skybluesofa_social_share');

class FacebookSocialPost
		extends NetworkSocialPost
{

	public $settingsGroupName = 'facebook';
	private $appId = ''; //Facebook App ID
	private $appSecret = ''; // Facebook App Secret
	public $permissions = 'publish_actions,manage_pages';  //Required facebook permissions
	protected $callbackURL = '';

	function __construct()
	{
		parent::__construct();

		$this->appId = $this->settings['app_id']['value'];
		$this->appSecret = $this->settings['app_secret']['value'];
		$this->callbackURL = BASE_URL . DIR_REL . $this->callbackURL;
	}

	public function isRevoked()
	{
		if (!$this->appId || !$this->appSecret) {
			$this->removeCredentials();
			return true;
		}
		try {
			$fb = new Facebook(array(
				'appId' => $this->appId,
				'secret' => $this->appSecret
			));
			$fb->setAccessToken($this->settings['oauth_token']['value']);
			if (!is_a($fb, "Facebook")) {
				$this->removeCredentials();
				return true;
			}

			try {
				$check = $fb->api("/me");
			} catch (FacebookApiException $e) {
				$this->removeCredentials();
				return true;
			}
		} catch (FacebookApiException $e) {
			$this->removeCredentials();
			return true;
		}
		return false;
	}

	public function getTimeline()
	{
		if ($this->settings['post_to_page']['value']) {
            $timeline = $this->getTimelineById($this->settings['post_to_page']['value']);
            if ($timeline['id']) {
                return $timeline;
            }
		}
		return false;
	}

	public function getUserTimelines()
	{
		$this->getUser();
		if ($this->user) {
			try {
                $timelines = $this->instance->api('/me/accounts');
                if (isset($timelines['data'])) {
                    $timelines = $timelines['data'];
                }
			} catch (FacebookApiException $e) {
                $timelines = false;
			}
			return $timelines;
		}
		return false;
	}

	public function getTimelineById($id)
	{
		$this->getFacebook();
		try {
            $timeline = $this->instance->api('/'.$id);
		} catch (FacebookApiException $e) {
            $timeline = false;
		}
		return isset($timeline['id']) ? $timeline : false;
	}

	public function getFacebook()
	{
		if ($this->instance) {
			return $this->instance;
		}
		Loader::library('3rdParty/facebookauth/inc/facebook', 'skybluesofa_social_share');
		$secret = $this->appSecret;
		if ($this->settings['oauth_token']['value']) {
			//$secret = $this->settings['oauth_token']['value'];
		}
		$this->instance = new Facebook(array(
			'appId' => $this->appId,
			'secret' => $secret
		));
		$this->instance->setAccessToken($this->settings['oauth_token']['value']);
		if (!is_a($this->instance, "Facebook")) {
			$this->updateCredentials(false);
			$this->instance = false;
		}
		return $this->instance;
	}

	public function getUser()
	{
		if (!$this->instance) {
			$this->getFacebook();
		}
		$this->user = $this->instance->getUser();
		return $this->user;
	}

	public function getUserName()
	{
		if (!$this->user) {
			$this->getUser();
		}
		$fql = 'SELECT name from user where uid = ' . $this->user;
		$ret_obj = $this->instance->api(array(
			'method' => 'fql.query',
			'query' => $fql,
		));
		return $ret_obj[0]['name'];
	}

	public function getUserPages()
	{
		if (!$this->user) {
			$this->getUser;
		}
		try {
			$user_profile = $this->instance->api('/me');
			//Get user pages details using Facebook Query Language (FQL)
			$fql_query = 'SELECT page_id, name, page_url FROM page WHERE page_id IN (SELECT page_id FROM page_admin WHERE uid=' . $this->user . ')';
			$this->pagesToPost = $this->instance->api(array('method' => 'fql.query', 'query' => $fql_query));
			return $this->pagesToPost;
		} catch (FacebookApiException $e) {
			echo $e->getMessage();
			$this->user = null;
			return false;
		}
	}

	public function getAuthorizeURL()
	{
		$this->getFacebook();
		return $this->instance->getLoginUrl(array('redirect_uri' => $this->callbackURL, 'scope' => $this->permissions));
	}

	public function saveCredentials()
	{
		// Facebook connection
		$instance = $this->getFacebook();
		$instance->setExtendedAccessToken();
		$oauth_token = $instance->getExtendedAccessToken();
		if ($oauth_token) {
			$this->updateCredentials($oauth_token);
			$returnValue = true;
		} else {
			$returnValue = false;
		}
		return $returnValue;
	}

	public function updateCredentials($oauth_token)
	{
		$this->saveSetting('oauth_token', $oauth_token);
		if ($oauth_token) {
			$connected = 1;
			$this->saveSetting('use', '1');
		} else {
			$connected = 0;
			$this->saveSetting('oauth_token', null);
		}
		$this->saveSetting('connected', $connected);
		$this->getSettings();
	}

	public function removeCredentials()
	{
		$this->updateCredentials(null);
		$this->saveSetting('post_to_page', '');
		$this->saveSetting('post_to_page_name', '');
		$this->getSettingsFromDB();
		$this->getSettings();
	}

	protected function generatePostContents()
	{
        $message = trim($this->prefix);
		if ($this->hashTags) {
			$message = $message . ' ' . $this->hashTags;
		}
		$postBody = array(
			'message' => $message,
			'name' => $this->pageName,
			//'caption' => $caption,
			'link' => $this->pageUrl,
			'description' => $this->pageDescription,
			'actions' => array(
				array(
					'name' => SITE,
					'link' => BASE_URL
				)
			)
		);
		if ($this->pageThumbnail) {
			$postBody['picture'] = $this->pageThumbnail;
		}
		return $postBody;
	}

	protected function postToNetwork($postContents)
	{
		$this->getFacebook();
		$success = false;
		if (is_array($this->settings) && $this->settings['use']['value']) {
			if ($this->settings['post_to_page']['value']) {
                $timelines = $this->getUserTimelines();
                $access_token = null;
                foreach ($timelines as $timeline) {
                    if ($timeline['id']==$this->settings['post_to_page']['value']) {
                        $access_token = $timeline['access_token'];
                    }
                }
                if ($access_token) {
                    $this->instance->setAccessToken($access_token);
                }
				$post_url = '/' . $this->settings['post_to_page']['value'] . '/feed';
				try {
					$postResult = $this->instance->api($post_url, 'post', $postContents);
					Log::addEntry('Page posted to Facebook: ' . print_r($postContents, true), 'Socializer');
					$success = true;
				} catch (FacebookApiException $e) {
					Log::addEntry('Error posting page to Facebook: ' . print_r($e, true), 'Socializer');
					$this->removeCredentials(false);
					$success = false;
				}
			}
		}
		return $success;
	}

}

?>